@@ -4,7 +4,7 @@ import time
 from .HTMLparsers import getSchiHubPDF, SciHubUrls
 import random
 from .NetInfo import NetInfo
-from .HTMLparsers import getLibgenPDF
+from .HTMLparsers import getLibgenPDF, LibgenUrls
 import re
 
 
@@ -124,6 +124,7 @@ def downloadlibgenPapers(papers, dwnl_dir, num_limit, libgen_results):
     num_downloaded = 0
     paper_number = 1
     paper_files = []
+    print(papers)
     for p in papers:
         print("Download {} of {} -> {}".format(paper_number, libgen_results, p['title']))
         paper_number += 1
@@ -141,13 +142,13 @@ def downloadlibgenPapers(papers, dwnl_dir, num_limit, libgen_results):
 
                         pdf_link = getLibgenPDF(r.text)
                         if(pdf_link != None):
-                            r = requests.get(link, headers=NetInfo.HEADERS)
+                            r = requests.get(p['link'], headers=NetInfo.HEADERS)
                             content_type = r.headers.get('content-type')
                             dwn_source = 1
                     if ('application/pdf' in content_type):
                         paper_files.append(saveFile(pdf_dir,r.content,p,dwn_source))
                         downloaded = True
-             
+
             except Exception:
                 pass
 
